Package: CodeDepends
Version: 0.6.7
Title: Analysis of R Code for Reproducible Research and Code
        Comprehension
Description: Tools for analyzing R expressions
  or blocks of code and determining the dependencies between them.
  It focuses on R scripts, but can be used on the bodies of functions.
  There are many facilities including the ability to summarize  or get a high-level
  view of code, determining dependencies between variables,  code improvement
  suggestions.
Authors@R: c(person(given = c("Duncan", "Temple"),
	            family = "Lang",
                    role = "aut"),
             person(given = "Roger",
                    family = "Peng",
                    role = "aut"),
             person(given = "Deborah",
                    family = "Nolan",
                    role = "aut"),
             person(given = "Gabriel",
                    family = "Becker",
		    role = c("aut", "cre"),
                    email = "gabembecker@gmail.com"))
License: GPL
URL: https://github.com/duncantl/CodeDepends
BugReports: https://github.com/duncantl/CodeDepends/issues
Depends: methods
Imports: codetools, graph, XML, utils
Suggests: Rgraphviz, RUnit, knitr, highlight, RJSONIO, RCurl, Rcpp
VignetteBuilder: knitr
Collate: classes.R librarySymbols.R functionHandlers.R codeDepends.R
        sectionDepends.R sweave.R xml.R jss.R frags.R codeTypes.R gc.R
        graph.R parallel.R deps.R separateBlocks.R callGraph.R isPlot.R
        isOutput.R refScript.R sideEffects.R highlightCode.R
        freeVariables.R convenienceFuns.R
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-03-02 23:43:18 UTC; gbecker
Author: Duncan Temple Lang [aut],
  Roger Peng [aut],
  Deborah Nolan [aut],
  Gabriel Becker [aut, cre]
Maintainer: Gabriel Becker <gabembecker@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-03 08:40:20 UTC
Built: R 4.6.0; ; 2026-04-25 17:44:20 UTC; unix
