Package: CodeDepends
Version: 0.6.6
Title: Analysis of R Code for Reproducible Research and Code
        Comprehension
Description: Tools for analyzing R expressions
  or blocks of code and determining the dependencies between them.
  It focuses on R scripts, but can be used on the bodies of functions.
  There are many facilities including the ability to summarize  or get a high-level
  view of code, determining dependencies between variables,  code improvement
  suggestions.
Author: Duncan Temple Lang, Roger Peng, Deborah Nolan, Gabriel Becker
Maintainer: Gabriel Becker <gabembecker@gmail.com>
License: GPL
URL: https://github.com/duncantl/CodeDepends
BugReports: https://github.com/duncantl/CodeDepends/issues
Depends: methods
Imports: codetools, graph, XML, utils
Suggests: Rgraphviz, RUnit, knitr, highlight, RJSONIO, RCurl, Rcpp
VignetteBuilder: knitr
Collate: classes.R librarySymbols.R functionHandlers.R codeDepends.R
        sectionDepends.R sweave.R xml.R jss.R frags.R codeTypes.R gc.R
        graph.R parallel.R deps.R separateBlocks.R callGraph.R isPlot.R
        isOutput.R refScript.R sideEffects.R highlightCode.R
        freeVariables.R convenienceFuns.R
NeedsCompilation: no
Packaged: 2024-04-07 21:08:18 UTC; gbecker
Repository: CRAN
Date/Publication: 2024-04-07 23:03:14 UTC
Built: R 4.3.3; ; 2025-01-24 05:49:38 UTC; unix
